A basic newsletter app for the Django webframework
--------------------------------------------------

* Please see the documentation in the docs folder. 

* You can reach the author of django-campaign at arne _at_ rcs4u.de.

* Bug-reports can be filed at the github project page: 
  https://github.com/arneb/django-campaign/
